@@ -7,6 +7,7 @@ import contextlib
 import errno
 import os
 import shutil
+import tempfile
 import uuid
 from hashlib import sha1
 from threading import Lock
@@ -118,7 +119,9 @@ class CacheHelper(object):
   @classmethod
   def _compute_hash(cls, names, stream_factory):
     digest = sha1()
-    digest.update(''.join(names).encode('utf-8'))
+    # Always use / as the path separator, since that's what zip uses.
+    hashed_names = [n.replace(os.sep, '/') for n in names]
+    digest.update(''.join(hashed_names).encode('utf-8'))
     for name in names:
       with contextlib.closing(stream_factory(name)) as fp:
         cls.update_hash(fp, digest)
@@ -136,7 +139,7 @@ class CacheHelper(object):
 
   @classmethod
   def _iter_files(cls, directory):
-    normpath = os.path.normpath(directory)
+    normpath = os.path.realpath(os.path.normpath(directory))
     for root, _, files in os.walk(normpath):
       for f in files:
         yield os.path.relpath(os.path.join(root, f), normpath)
@@ -200,3 +203,19 @@ class Memoizer(object):
   def store(self, key, value):
     with self._lock:
       self._data[key] = value
+
+
+@contextlib.contextmanager
+def named_temporary_file(*args, **kwargs):
+  """
+  Due to a bug in python (https://bugs.python.org/issue14243), we need
+  this to be able to use the temporary file without deleting it.
+  """
+  assert 'delete' not in kwargs
+  kwargs['delete'] = False
+  fp = tempfile.NamedTemporaryFile(*args, **kwargs)
+  try:
+    with fp:
+      yield fp
+  finally:
+    os.remove(fp.name)
